<?php
/**
* 2007-2015 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2015 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

class freeshippingproduct extends Module
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'freeshippingproduct';
        $this->tab = 'shipping_logistics';
        $this->version = '1.0.0';
        $this->author = 'PrestaMarketing™';
        $this->need_instance = 1;

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Free Shipping by product');
        $this->description = $this->l('Set products with shipping free');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall the module and all your relations?');

        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        if (Configuration::get('freeshippingproduct_ID_CARRIER')) {
            $carrier = new Carrier(Configuration::get('freeshippingproduct_ID_CARRIER'));
            $carrier->delete();
            unset($carrier);
        }
        $delay = array();

        foreach ($this->context->controller->getLanguages() as $key => $value) {
            $delay[$value['id_lang']] =  $this->l('24 and 72 hours');
        }
        $carrier = new Carrier();
        $carrier->name = 'freeshippingproduct';
        $carrier->delay = $delay;
        $carrier->active = false;
        $carrier->is_free = true;
        $carrier->save();
        
        Configuration::updateValue('freeshippingproduct_ID_CARRIER', $carrier->id);
        /*Configuration::updateValue('PMKT_licence_FREESHIPROD','');
        Configuration::updateValue('PMKT_key_FREESHIPROD','');*/

        include(dirname(__FILE__).'/sql/install.php');

        return parent::install() &&
            $this->registerHook('header') &&
            $this->registerHook('backOfficeHeader') &&
            $this->registerHook('actionCarrierProcess') &&
            $this->registerHook('actionProductSave') &&
            $this->registerHook('displayAdminProductsExtra') &&
            $this->registerHook('displayBeforeCarrier');
    }

    public function uninstall()
    {
        Configuration::deleteByName('freeshippingproduct_LIVE_MODE');
        /*Configuration::deleteByName('PMKT_licence_FREESHIPROD');
        Configuration::deleteByName('PMKT_key_FREESHIPROD');*/

        include(dirname(__FILE__).'/sql/uninstall.php');

        return parent::uninstall();
    }

    /**
     * Load the configuration form
     */
    public function getContent()
    {
        $output = '';

        /*if(Tools::isSubmit('activationCode')) {

            if(Configuration::get('PMKT_licence_FREESHIPROD') == '') {
                require_once(_PS_MODULE_DIR_.'freeshippingproduct/lib/nusoap/lib/nusoap.php');
                $wsdl='http://prestamarketing.com/modules/PMKT_API/PMKT_API/active.php?wsdl';
                $client = new nusoap_client($wsdl,'wsdl');
                $param = array(
                    'key' => Tools::getValue('activationCode'),
                    'host' => $_SERVER['SERVER_NAME'], 
                    'ip' => $_SERVER['REMOTE_ADDR']
                );
                $response = $client->call('activeKey',$param);
                if ($response != '') {
                    Configuration::updateValue('PMKT_licence_FREESHIPROD',$response);
                    Configuration::updateValue('PMKT_key_FREESHIPROD',Tools::getValue('activationCode'));
                } else {
                    $output .= $this->displayError($this->l('Incorrect license number 
                        if the problem persists please 
                        contact soporte@prestamarketing.com'));
                }
            }
        }

        if(Configuration::get('PMKT_licence_FREESHIPROD') == '') {
            $output .= @$this->formActivacion();
            return $output;
        }     */       

        /**
         * If values have been submitted in the form, process.
         */
        if (((bool)Tools::isSubmit('submitfreeshippingproductModule')) == true) {
            $this->postProcess();
        }       
        $output = '<div class="col-md-12 form-content">';
        $output .= $this->renderForm();
        $output .= '</div>';
        $output .= '<div class="col-md-12 panel help-panel panel-info">';
        $output .= $this->context->smarty->fetch($this->local_path.'views/templates/admin/aside.tpl');
        $output .= '</div>';
        $output .= '<div class="col-md-12 module-footer">';
        $output .= $this->context->smarty->fetch($this->local_path.'views/templates/admin/footer.tpl');
        $output .= '</div>';
        return $output;
    }

    public function formActivacion()
    {   
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');
        
        $fields_form[0]['form'] = array(
            'legend' => array(
                'title' => $this->l('Module activation'),
            ),
            'input' => array(
                array(
                    'type' => 'text',
                    'label' => $this->l('Code'),
                    'name' => 'activationCode',
                    'desc' => $this->l('leave this field empty in localhost'),
                    'size' => 40,
                    'required' => true
                ),
                
            ),
            'submit' => array(
                'title' => $this->l('Send'),
                'class' => 'button'
            )
        );
         
        $helper = new HelperForm();
         
        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;
         
        // Language
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;
         
        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = true;        // false -> remove toolbar
        $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
        $helper->submit_action = 'submit'.$this->name;
        $helper->toolbar_btn = array(
            'save' =>
            array(
                'desc' => $this->l('Save'),
                'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.
                '&token='.Tools::getAdminTokenLite('AdminModules'),
            ),
            'back' => array(
                'href' => AdminController::$currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            )
        );       
        return $helper->generateForm($fields_form);
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitfreeshippingproductModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {
        $carriers = Carrier::getCarriers($this->context->language->id);
        return array(
            'form' => array(
                'legend' => array(
                'title' => $this->l('Settings'),
                'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'type' => 'select',
                        'label' => $this->l('Carrier'),
                        'name' => 'freeshippingproduct_ID_CARRIER',
                        'is_bool' => true,
                        'desc' => $this->l('For using in the module, this carrier has to be deactivated in Carriers.'),
                        'options' => array(
                            'query' => $carriers,
                            'id' => 'id_carrier',
                            'name' => 'name',
                        ),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }

    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        return array(
            'freeshippingproduct_ID_CARRIER' => Configuration::get('freeshippingproduct_ID_CARRIER'),
        );
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();

        foreach (array_keys($form_values) as $key) {
            Configuration::updateValue($key, Tools::getValue($key));
        }
    }

    /**
    * Add the CSS & JavaScript files you want to be loaded in the BO.
    */
    public function hookBackOfficeHeader()
    {
        if (Tools::getValue('module_name') == $this->name) {
            $this->context->controller->addJS($this->_path.'views/js/back.js');
            $this->context->controller->addCSS($this->_path.'views/css/back.css');
        }
    }

    /**
     * Add the CSS & JavaScript files you want to be added on the FO.
     */
    public function hookHeader()
    {
        $this->context->controller->addJS($this->_path.'/views/js/front.js');
        $this->context->controller->addCSS($this->_path.'/views/css/front.css');
    }

    public function hookActionCarrierProcess($params)
    {
       
    }

    public function hookActionProductSave($params)
    {
        $id_product = Tools::getValue('id_product');

        $val = Tools::getValue('freeshippingproduct');

        if ($val == 1) {
            $sql = sprintf("SELECT id_freeshippingproduct 
                FROM %sfreeshippingproduct 
                WHERE id_freeshippingproduct = %d", _DB_PREFIX_, (int)$id_product);
            $result = DB::getInstance()->executeS($sql);
            
            if (count($result) == 0) {
                $sql = sprintf("INSERT INTO %sfreeshippingproduct VALUES (%d)", _DB_PREFIX_, (int)$id_product);
                DB::getInstance()->execute($sql);
            } 
        } else {
            $sql = sprintf("SELECT id_freeshippingproduct 
                FROM %sfreeshippingproduct 
                WHERE id_freeshippingproduct = %d", _DB_PREFIX_, (int)$id_product);
            $result = DB::getInstance()->executeS($sql);
            
            if (count($result) > 0) {
                $sql = sprintf("DELETE FROM %sfreeshippingproduct WHERE id_freeshippingproduct =%d", _DB_PREFIX_, (int)$id_product);
                DB::getInstance()->execute($sql);
            }  
        }
    }

    public function hookDisplayBeforeCarrier($params)
    {
        /* Place your code here. */
        $carrier = new Carrier(Configuration::get('freeshippingproduct_ID_CARRIER'));
        $caux = array();
        $caux['name'] = $carrier->name;
        $caux['img'] = '';
        $caux['delay'] = $carrier->delay[$this->context->language->id];
        $caux['price'] = 0;
        $caux['price_tax_exc'] = 0;
        $caux['id_carrier'] = $carrier->id;
        $caux['is_module'] = $carrier->is_module;
        
    }

    public function hookDisplayAdminProductsExtra($params)
    {
        /*if(Configuration::get('PMKT_licence_FREESHIPROD') != '') {*/
            $id_product = Tools::getValue('id_product');

            
            $sql = sprintf("SELECT id_freeshippingproduct 
                FROM %sfreeshippingproduct 
                WHERE id_freeshippingproduct = %d", _DB_PREFIX_, (int)$id_product);
            $result = DB::getInstance()->executeS($sql);

            $selected = false;
            if (count($result) != 0) {
                $selected = true;
            }
            $this->context->smarty->assign(array(
                'selected' => $selected,
            ));

            $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/product.tpl');

            return $output;
        /*} else {
            return $this->l('you have to validate your licence number');
        }*/
    }
}
